pub struct SamConnection { /* private fields */ }Implementations
Sourceimpl SamConnection
impl SamConnection
pub fn connect<A: ToSocketAddrs>( addr: A, min_version: &str, max_version: &str, ) -> Result<SamConnection, Error>
pub fn naming_lookup(&mut self, name: &str) -> Result<String, Error>
pub fn gen(&mut self, sig_type: SigType) -> Result<(String, String), Error>
pub fn duplicate(&self) -> Result<SamConnection>
Sourcepub fn send_msg(&mut self, to: String, msg: Vec<u8>)
pub fn send_msg(&mut self, to: String, msg: Vec<u8>)
Ping request to peer based on established session Listener waiting for Ping request from peer on established session
pub fn recv_msg(&mut self) -> Result<(String, Vec<u8>), Error>